@@ -46,7 +46,7 @@ class CfnBudget(
         id: builtins.str,
         *,
         budget: typing.Union["CfnBudget.BudgetDataProperty", aws_cdk.core.IResolvable],
-        notifications_with_subscribers: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnBudget.NotificationWithSubscribersProperty"]]]] = None,
+        notifications_with_subscribers: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnBudget.NotificationWithSubscribersProperty"]]]] = None,
     ) -> None:
         '''Create a new ``AWS::Budgets::Budget``.
 
@@ -575,7 +575,7 @@ class CfnBudget(
             self,
             *,
             notification: typing.Union[aws_cdk.core.IResolvable, "CfnBudget.NotificationProperty"],
-            subscribers: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnBudget.SubscriberProperty"]]],
+            subscribers: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnBudget.SubscriberProperty"]]],
         ) -> None:
             '''
             :param notification: ``CfnBudget.NotificationWithSubscribersProperty.Notification``.
@@ -793,7 +793,7 @@ class CfnBudgetProps:
         self,
         *,
         budget: typing.Union[CfnBudget.BudgetDataProperty, aws_cdk.core.IResolvable],
-        notifications_with_subscribers: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnBudget.NotificationWithSubscribersProperty]]]] = None,
+        notifications_with_subscribers: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnBudget.NotificationWithSubscribersProperty]]]] = None,
     ) -> None:
         '''Properties for defining a ``AWS::Budgets::Budget``.
 
